@@ -1,7 +1,7 @@
 ################################################################################
 ### Package Setup
 ###
-### Copyright (C) 2009-2014,2018-2021 Sebastian Meyer
+### Copyright (C) 2009-2014,2018-2021,2023 Sebastian Meyer
 ###
 ### This file is part of the R package "polyCub",
 ### free software under the terms of the GNU General Public License, version 2,
@@ -16,9 +16,7 @@
 #' It solves the problem of integrating a continuously differentiable
 #' function \eqn{f(x,y)} over simple closed polygons.
 #'
-#' \pkg{polyCub} provides the following cubature methods,
-#' which can either be called explicitly or via the generic
-#' \code{\link{polyCub}} function:
+#' \pkg{polyCub} provides the following cubature methods:
 #' \describe{
 #' \item{\code{\link{polyCub.SV}}:}{
 #' General-purpose \emph{product Gauss cubature} (Sommariva and Vianello, 2007)
@@ -33,25 +31,19 @@
 #' via line \code{\link{integrate}()} along the polygon boundary
 #' (Meyer and Held, 2014, Supplement B, Section 2.4).
 #' }
-#' \item{\code{\link{polyCub.exact.Gauss}}:}{
-#' Accurate (but slow) integration of the \emph{bivariate Gaussian density}
-#' based on polygon triangulation (via \code{\link[gpclib]{tristrip}} from
-#' \pkg{gpclib}) and (numerous) evaluations of cumulative densities (via
-#' \code{\link[mvtnorm]{pmvnorm}} from package \pkg{mvtnorm}).
-#' Note that there is also a function \code{\link{circleCub.Gauss}}
-#' to integrate the \emph{isotropic} Gaussian density over a
-#' \emph{circular domain}.
 #' }
-#' }
-#' A more detailed description and benchmark experiment of the above cubature
-#' methods can be found in the \code{vignette("polyCub")} and in
-#' Meyer (2010, Section 3.2).
+#' A brief description and benchmark experiment of the above cubature
+#' methods can be found in the \code{vignette("polyCub")}.
 #'
+#' There is also \code{\link{polyCub.exact.Gauss}}, intended to
+#' accurately (but slowly) integrate the \emph{bivariate Gaussian density};
+#' however, this implementation is disabled as of \pkg{polyCub} 0.9.0:
+#' it needs a reliable implementation of polygon triangulation.
+#'
+#' Meyer (2010, Section 3.2) discusses and compares some of these methods.
+#'
+#' @author Sebastian Meyer
 #' @references
-#' Abramowitz, M. and Stegun, I. A. (1972).
-#' \emph{Handbook of Mathematical Functions with Formulas, Graphs, and
-#' Mathematical Tables}. New York: Dover Publications.
-#'
 #' Baddeley, A., Rubak, E. and Turner, R. (2015).
 #' \emph{Spatial Point Patterns: Methodology and Applications with R}.
 #' Chapman and Hall/CRC Press, London.
@@ -70,45 +62,30 @@
 #' Product Gauss cubature over polygons based on Green's integration formula.
 #' \emph{BIT Numerical Mathematics}, \bold{47} (2), 441-453.
 #' \doi{10.1007/s10543-007-0131-2}
-#' @docType package
-#' @name polyCub-package
 #' @seealso
 #' \code{vignette("polyCub")}
 #'
 #' For the special case of a rectangular domain along the axes
-#' (e.g., a bounding box), the \pkg{cubature} package is more appropriate.
-NULL
+#' (e.g., a bounding box), the \CRANpkg{cubature} package is more appropriate.
+"_PACKAGE"
 
 
-.Options <- new.env()
 
-.onLoad <- function (libname, pkgname)
-{
-    .Options$gpclib <- FALSE
-}
-
-gpclibCheck <- function (fatal = TRUE)
-{
-    gpclibOK <- .Options$gpclib
-    if (!gpclibOK && fatal)
-        stop("acceptance of the gpclib license is required; see ",
-             sQuote("help(gpclibPermit)"))
-    gpclibOK
-}
-
-#' \pkg{gpclib} License Acceptance
+#' \pkg{gpclib} License Acceptance (OBSOLETE)
+#'
+#' Previous versions of package \CRANpkg{gpclib} had a restricted license
+#' (commercial use prohibited) and these functions were used as a blocker.
+#' They now always return \code{TRUE}.
 #'
-#' Similar to the handling in package \pkg{maptools}, these functions
-#' explicitly accept the restricted \pkg{gpclib} license (commercial use
-#' prohibited) and report its acceptance status, respectively.
 #' \pkg{gpclib} functionality is only required for
 #' \code{\link{polyCub.exact.Gauss}}.
+#' @keywords internal
 #' @export
 gpclibPermit <- function ()
 {
-    if (requireNamespace("gpclib")) .Options$gpclib <- TRUE
+    ##requireNamespace("gpclib")
     gpclibPermitStatus()
 }
 #' @rdname gpclibPermit
 #' @export
-gpclibPermitStatus <- function () gpclibCheck(fatal=FALSE)
+gpclibPermitStatus <- function () TRUE
